@@ -5,17 +5,15 @@ use warnings;
 use Carp;
 use Time::HiRes;
 
-our $VERSION = 0.27;
+our $VERSION = 0.28;
 
 use Geo::Coder::Many::Bing;
 use Geo::Coder::Many::Google;
 use Geo::Coder::Many::Googlev3;
 use Geo::Coder::Many::Mapquest;
-use Geo::Coder::Many::Multimap;
 use Geo::Coder::Many::OSM;
 use Geo::Coder::Many::Ovi;
 use Geo::Coder::Many::PlaceFinder;
-use Geo::Coder::Many::SimpleGeo;
 
 use Geo::Coder::Many::Util qw(
     min_precision_filter 
@@ -814,7 +812,6 @@ Currently supported Geo::Coder::* modules are:
   Geo::Coder::OSM
   Geo::Coder::Ovi
   Geo::Coder::PlaceFinder
-  Geo::Coder::SimpleGeo
 
 =head1 SEE ALSO
 
@@ -826,7 +823,6 @@ Currently supported Geo::Coder::* modules are:
   Geo::Coder::OSM
   Geo::Coder::Ovi
   Geo::Coder::PlaceFinder
-  Geo::Coder::SimpleGeo
 
 Ed Freyfogle delivered a talk about Remote Geocoding and the
 motivation for Geo::Coder::Many at the 2010 London Perl
